%HYDROLOGYDC class definition
%
%   Usage:
%      hydrologydc=hydrologydc();

classdef hydrologydc
    properties (SetAccess=public) 
        spcsediment_head          = NaN;
        sediment_compressibility = 0;
        sediment_porosity         = 0;
        ssediment_thickness      = 0;
        sediment_transmitivity    = 0;
        water_compressibility     = 0;
        water_density             = 0;
    end
    methods
        function obj = hydrologydc(varargin) % {{{
            switch nargin
              case 0
                obj=setdefaultparameters(obj);
              otherwise
                error('constructor not supported');
            end
        end % }}}
        function obj = setdefaultparameters(obj) % {{{
            
        %Parameters from de Fleurian 2013
            obj.sediment_compressibility = 1.0e-08;
            obj.sediment_porosity         = .4;
            obj.sediment_thickness        = 20.0;
            obj.sediment_transmitivity    = 8.0e-04;
            obj.water_compressibility     = 5.04e-10;
            obj.water_density             = 1.0e+03;
            
        end % }}}
        function md = checkconsistency(obj,md,solution,analyses) % {{{
            
        %Early return
            if ~ismember(HydrologyAnalysisEnum(),analyses), return; end
            
            md = checkfield(md,'hydrology.spcsediment_head','forcing',1);
            md = checkfield(md,'hydrology.sediment_compressibility','>',0,'numel',1);
            md = checkfield(md,'hydrology.sediment_porosity','>',0,'numel',1);
            md = checkfield(md,'hydrology.sediment_thickness','>',0,'numel',1);
            md = checkfield(md,'hydrology.sediment_transmitivity','>',0,'numel',1);
            md = checkfield(md,'hydrology.water_compressibility','>',0,'numel',1);
            md = checkfield(md,'hydrology.water_density','>',0,'numel',1);
        end % }}}
        function disp(obj) % {{{
            disp(sprintf('   hydrology Dual Porous Continuum Equivalent parameters:'));
            
            fielddisplay(obj,'spcsediment_head','sediment water head constraints (NaN means no constraint, meters above MSL)');
            fielddisplay(obj,'sediment_compressibility','sediment compressibility (Pa -1)');
            fielddisplay(obj,'sediment_porosity','sediment(dimensionless)');
            fielddisplay(obj,'sediment_thickness','sediment thickness (meters)');
            fielddisplay(obj,'sediment_transmitivity','sediment transmitivity (m2 s-1)');
            fielddisplay(obj,'water_compressibility','water compressibility (Pa -1)');
            fielddisplay(obj,'water_density','water density (kg m 3)');
            
        end % }}}
        function marshall(obj,fid) % {{{
			WriteData(fid,'enum',HydrologyEnum(),'data',HydrologydcEnum(),'format','Integer');
			WriteData(fid,'object',obj,'fieldname','spcsediment_head','format','DoubleMat','mattype',1);
			WriteData(fid,'object',obj,'fieldname','sediment_compressibility','format','Double');			
                        WriteData(fid,'object',obj,'fieldname','sediment_porosity','format','Double');			
                        WriteData(fid,'object',obj,'fieldname','sediment_thickness','format','Double');
                        WriteData(fid,'object',obj,'fieldname','sediment_transmitivity','format','Double');			
                        WriteData(fid,'object',obj,'fieldname','water_compressibility','format','Double');			
                        WriteData(fid,'object',obj,'fieldname','water_density','format','Double');
                    end % }}}
    end
end
